==> jc-1.4.0.tar.gz: soot/dava/DavaPrinter.h <==
// public class soot.dava.DavaPrinter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 88210a702cbfd53 soot_dava_DavaPrinter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_DavaPrinter_H_
#define _JC_soot_dava_DavaPrinter_H_

// Forward structure declarations
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_dava_DavaPrinter$object;

// Typedefs
typedef struct _jc_soot_dava_DavaPrinter$sub_refs	_jc_soot_dava_DavaPrinter$sub_refs;
typedef struct _jc_soot_dava_DavaPrinter$sub_nonrefs	_jc_soot_dava_DavaPrinter$sub_nonrefs;
typedef struct _jc_soot_dava_DavaPrinter$refs	_jc_soot_dava_DavaPrinter$refs;
typedef struct _jc_soot_dava_DavaPrinter$nonrefs	_jc_soot_dava_DavaPrinter$nonrefs;
typedef struct _jc_soot_dava_DavaPrinter$object	_jc_soot_dava_DavaPrinter$object;

typedef const struct _jc_soot_dava_DavaPrinter$vmethods	_jc_soot_dava_DavaPrinter$vmethods;
typedef const struct _jc_soot_dava_DavaPrinter$vtable	_jc_soot_dava_DavaPrinter$vtable;
typedef const struct _jc_soot_dava_DavaPrinter$vtype	_jc_soot_dava_DavaPrinter$vtype;

// Constructors
extern void _jc_soot_dava_DavaPrinter$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_dava_DavaPrinter$method$printLocalsInBody$dec46c6c6fadbf71(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *);
extern void _jc_soot_dava_DavaPrinter$method$printStatementsInBody$b89b48aaeb06493a(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *);
extern void _jc_soot_dava_DavaPrinter$method$printTo$214cc2e56a1b04d1(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *);
extern void _jc_soot_dava_DavaPrinter$method$printTo$6eca094e8566bf07(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_SootClass$object *, struct _jc_java_io_PrintWriter$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_DavaPrinter$method_info$printLocalsInBody$dec46c6c6fadbf71;
extern _jc_method _jc_soot_dava_DavaPrinter$method_info$printStatementsInBody$b89b48aaeb06493a;
extern _jc_method _jc_soot_dava_DavaPrinter$method_info$printTo$214cc2e56a1b04d1;
extern _jc_method _jc_soot_dava_DavaPrinter$method_info$printTo$6eca094e8566bf07;

// Static methods
extern struct _jc_soot_dava_DavaPrinter$object *_jc_soot_dava_DavaPrinter$method$v$000489e64e2c7e62(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_DavaPrinter$vmethods {
	void	(*printLocalsInBody$dec46c6c6fadbf71)(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *);
	void	(*printStatementsInBody$b89b48aaeb06493a)(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *);
	void	(*printTo$214cc2e56a1b04d1)(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *);
	void	(*printTo$6eca094e8566bf07)(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_SootClass$object *, struct _jc_java_io_PrintWriter$object *);
};

// Vtable
struct _jc_soot_dava_DavaPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_DavaPrinter$vmethods	soot_dava_DavaPrinter;
};

// Vtype
struct _jc_soot_dava_DavaPrinter$vtype {
	_jc_type			type;
	_jc_soot_dava_DavaPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_DavaPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_DavaPrinter$refs {
    _jc_soot_dava_DavaPrinter$sub_refs	soot_dava_DavaPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_DavaPrinter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_DavaPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_DavaPrinter$sub_nonrefs	soot_dava_DavaPrinter;
};

// Object instance structure
struct _jc_soot_dava_DavaPrinter$object {
	_jc_soot_dava_DavaPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_DavaPrinter$vtype	*vtype;
	_jc_soot_dava_DavaPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_DavaPrinter$vtype _jc_soot_dava_DavaPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_DavaPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_DavaPrinter$class_object;

#endif	/* _JC_soot_dava_DavaPrinter_H_ */

==> jc-1.4.6.tar.gz: soot/dava/DavaPrinter.h <==
// public class soot.dava.DavaPrinter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 88210a702cbfd53 soot_dava_DavaPrinter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_DavaPrinter_H_
#define _JC_soot_dava_DavaPrinter_H_

// Forward structure declarations
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_dava_DavaPrinter$object;

// Typedefs
typedef struct _jc_soot_dava_DavaPrinter$sub_refs	_jc_soot_dava_DavaPrinter$sub_refs;
typedef struct _jc_soot_dava_DavaPrinter$sub_nonrefs	_jc_soot_dava_DavaPrinter$sub_nonrefs;
typedef struct _jc_soot_dava_DavaPrinter$refs	_jc_soot_dava_DavaPrinter$refs;
typedef struct _jc_soot_dava_DavaPrinter$nonrefs	_jc_soot_dava_DavaPrinter$nonrefs;
typedef struct _jc_soot_dava_DavaPrinter$object	_jc_soot_dava_DavaPrinter$object;

typedef const struct _jc_soot_dava_DavaPrinter$vmethods	_jc_soot_dava_DavaPrinter$vmethods;
typedef const struct _jc_soot_dava_DavaPrinter$vtable	_jc_soot_dava_DavaPrinter$vtable;
typedef const struct _jc_soot_dava_DavaPrinter$vtype	_jc_soot_dava_DavaPrinter$vtype;

// Constructors
extern void _jc_soot_dava_DavaPrinter$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_DavaPrinter$method$printLocalsInBody$dec46c6c6fadbf71(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_DavaPrinter$method$printStatementsInBody$b89b48aaeb06493a(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_DavaPrinter$method$printTo$214cc2e56a1b04d1(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_DavaPrinter$method$printTo$6eca094e8566bf07(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_SootClass$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_DavaPrinter$method_info$printLocalsInBody$dec46c6c6fadbf71;
extern _jc_method _jc_soot_dava_DavaPrinter$method_info$printStatementsInBody$b89b48aaeb06493a;
extern _jc_method _jc_soot_dava_DavaPrinter$method_info$printTo$214cc2e56a1b04d1;
extern _jc_method _jc_soot_dava_DavaPrinter$method_info$printTo$6eca094e8566bf07;

// Static methods
extern struct _jc_soot_dava_DavaPrinter$object *_jc_soot_dava_DavaPrinter$method$v$000489e64e2c7e62(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_DavaPrinter$vmethods {
	void	(*printLocalsInBody$dec46c6c6fadbf71)(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
	void	(*printStatementsInBody$b89b48aaeb06493a)(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
	void	(*printTo$214cc2e56a1b04d1)(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_Body$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
	void	(*printTo$6eca094e8566bf07)(_jc_env *, struct _jc_soot_dava_DavaPrinter$object *, struct _jc_soot_SootClass$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_DavaPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_DavaPrinter$vmethods	soot_dava_DavaPrinter;
};

// Vtype
struct _jc_soot_dava_DavaPrinter$vtype {
	_jc_type			type;
	_jc_soot_dava_DavaPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_DavaPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_DavaPrinter$refs {
    _jc_soot_dava_DavaPrinter$sub_refs	soot_dava_DavaPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_DavaPrinter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_DavaPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_DavaPrinter$sub_nonrefs	soot_dava_DavaPrinter;
};

// Object instance structure
struct _jc_soot_dava_DavaPrinter$object {
	_jc_soot_dava_DavaPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_DavaPrinter$vtype	*vtype;
	_jc_soot_dava_DavaPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_DavaPrinter$vtype _jc_soot_dava_DavaPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_DavaPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_DavaPrinter$class_object;

#endif	/* _JC_soot_dava_DavaPrinter_H_ */
